@@ -20,5 +20,5 @@ public:
 
 protected:
     int percentageToAbsoluteQuality(const std::optional<quint8> &quality) override;
-    void applyEncodingPreference(AVDictionary *options) override;
+    AVDictionary *buildEncodingOptions() override;
 };
